@@ -53,6 +53,7 @@ import (
 
 	nropv1alpha1 "github.com/openshift-kni/numaresources-operator/api/numaresourcesoperator/v1alpha1"
 	"github.com/openshift-kni/numaresources-operator/pkg/apply"
+	"github.com/openshift-kni/numaresources-operator/pkg/hash"
 	"github.com/openshift-kni/numaresources-operator/pkg/loglevel"
 	"github.com/openshift-kni/numaresources-operator/pkg/machineconfigpools"
 	"github.com/openshift-kni/numaresources-operator/pkg/objectnames"
@@ -157,16 +158,29 @@ func (r *NUMAResourcesOperatorReconciler) Reconcile(ctx context.Context, req ctr
 func (r *NUMAResourcesOperatorReconciler) updateStatus(ctx context.Context, instance *nropv1alpha1.NUMAResourcesOperator, condition string, reason string, message string) (ctrl.Result, error) {
 	klog.Error(message)
 
-	if err := status.Update(ctx, r.Client, instance, condition, reason, message); err != nil {
+	if _, err := updateStatus(ctx, r.Client, instance, condition, reason, message); err != nil {
 		klog.InfoS("Failed to update numaresourcesoperator status", "Desired condition", status.ConditionDegraded, "error", err)
 		return ctrl.Result{}, err
 	}
-
 	// we do not return an error here because to pass the validation error a user will need to update NRO CR
 	// that will anyway initiate to reconcile loop
 	return ctrl.Result{}, nil
 }
 
+func updateStatus(ctx context.Context, cli client.Client, rte *nropv1alpha1.NUMAResourcesOperator, condition string, reason string, message string) (bool, error) {
+
+	conditions, ok := status.GetUpdatedConditions(rte.Status.Conditions, condition, reason, message)
+	if !ok {
+		return false, nil
+	}
+	rte.Status.Conditions = conditions
+
+	if err := cli.Status().Update(ctx, rte); err != nil {
+		return false, errors.Wrapf(err, "could not update status for object %s", client.ObjectKeyFromObject(rte))
+	}
+	return true, nil
+}
+
 func messageFromError(err error) string {
 	if err == nil {
 		return ""
@@ -301,10 +315,23 @@ func (r *NUMAResourcesOperatorReconciler) syncNUMAResourcesOperatorResources(ctx
 	if err != nil {
 		return daemonSetsNName, err
 	}
+	err = rtestate.UpdateDaemonSetPauseContainerSettings(r.RTEManifests.DaemonSet)
+	if err != nil {
+		return daemonSetsNName, err
+	}
 	if err = loglevel.UpdatePodSpec(&r.RTEManifests.DaemonSet.Spec.Template.Spec, instance.Spec.LogLevel); err != nil {
 		return daemonSetsNName, err
 	}
 
+	// ConfigMap should be provided by the kubeletconfig reconciliation loop
+	if r.RTEManifests.ConfigMap != nil {
+		cmHash, err := hash.ComputeCurrentConfigMap(ctx, r.Client, r.RTEManifests.ConfigMap)
+		if err != nil {
+			return daemonSetsNName, err
+		}
+		rtestate.UpdateDaemonSetHashAnnotation(r.RTEManifests.DaemonSet, cmHash)
+	}
+
 	existing := rtestate.FromClient(ctx, r.Client, r.Platform, r.RTEManifests, instance, mcps, r.Namespace)
 	for _, objState := range existing.State(r.RTEManifests, r.Platform, instance, mcps) {
 		if err := controllerutil.SetControllerReference(instance, objState.Desired, r.Scheme); err != nil {
