@@ -30,6 +30,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/resource"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/klog/v2"
@@ -275,7 +276,7 @@ var _ = Describe("[serial][disruptive][scheduler] workload placement", func() {
 				corev1.ResourceCPU:    resource.MustParse("6"),
 				corev1.ResourceMemory: resource.MustParse("6Gi"),
 			}
-			pod.Spec.Containers[0].Name = "testcnt-1"
+			pod.Spec.Containers[1].Name = "testcnt-1"
 			pod.Spec.Containers[1].Resources.Limits = corev1.ResourceList{
 				corev1.ResourceCPU:    resource.MustParse("12"),
 				corev1.ResourceMemory: resource.MustParse("8Gi"),
@@ -518,7 +519,7 @@ var _ = Describe("[serial][disruptive][scheduler] workload placement", func() {
 		It("[test_id:48713] a guaranteed pod with one container should be scheduled into one NUMA zone", func() {
 
 			By("Scheduling the testing pod")
-			pod := objects.NewTestPodPause(fxt.Namespace.Name, "testPod")
+			pod := objects.NewTestPodPause(fxt.Namespace.Name, "testpod")
 			pod.Spec.SchedulerName = schedulerName
 			pod.Spec.Containers[0].Resources.Limits = requiredRes
 
@@ -1049,8 +1050,30 @@ func makePaddingPod(namespace, nodeName string, zone nrtv1alpha1.Zone, podReqs c
 
 	klog.Infof("padding resource to saturate %q: %s", nodeName, e2ereslist.ToString(paddingReqs))
 
-	padPod := objects.NewTestPodPause(namespace, fmt.Sprintf("padpod-%s-%s", nodeName, zone.Name))
-	padPod.Spec.Containers[0].Resources.Limits = paddingReqs
+	var zero int64
+	padPod := &corev1.Pod{
+		ObjectMeta: metav1.ObjectMeta{
+			GenerateName: "padpod-",
+			Namespace:    namespace,
+			Labels: map[string]string{
+				"e2e-serial-pad-node":     nodeName,
+				"e2e-serial-pad-numazone": zone.Name,
+			},
+		},
+		Spec: corev1.PodSpec{
+			TerminationGracePeriodSeconds: &zero,
+			Containers: []corev1.Container{
+				{
+					Name:    "padpod-cnt-0",
+					Image:   objects.PauseImage,
+					Command: []string{objects.PauseCommand},
+					Resources: corev1.ResourceRequirements{
+						Limits: paddingReqs,
+					},
+				},
+			},
+		},
+	}
 	return padPod, nil
 }
 
